FunctionalInteraction
=====================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: FunctionalInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~FunctionalInteraction.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
